@@ -34,7 +34,9 @@ class AbstractFitFunction(ABC):
     _param_names = NotImplemented  # type: Tuple[str, ...]
 
     def __init__(
-        self, params: Tuple[float, ...] = None, param_errors: Tuple[float, ...] = None,
+        self,
+        params: Tuple[float, ...] = None,
+        param_errors: Tuple[float, ...] = None,
     ):
         """
         Parameters
@@ -49,12 +51,7 @@ class AbstractFitFunction(ABC):
 
         """
 
-        self.FitParamTuple = namedtuple("FitParamTuple", self._param_names)
-        """
-        A `~collections.namedtuple` used for attributes :attr:`params` and
-        :attr:`param_errors`.  The attribute :attr:`parameter_names` defines
-        the tuple field names.
-        """
+        self._FitParamTuple = namedtuple("FitParamTuple", self._param_names)
 
         if params is None:
             self._params = None
@@ -219,6 +216,15 @@ class AbstractFitFunction(ABC):
         """
         return self._curve_fit_results
 
+    @property
+    def FitParamTuple(self):
+        """
+        A `~collections.namedtuple` used for attributes :attr:`params` and
+        :attr:`param_errors`.  The attribute :attr:`parameter_names` defines
+        the tuple field names.
+        """
+        return self._FitParamTuple
+
     @property
     def params(self) -> Union[None, tuple]:
         """The fitted parameters for the fit function."""
@@ -323,8 +329,8 @@ class AbstractFitFunction(ABC):
                 or np.issubdtype(x.dtype, np.floating)
             ):
                 raise TypeError(
-                    f"Argument x needs to be an array_like object of integers "
-                    f"or floats."
+                    "Argument x needs to be an array_like object of integers "
+                    "or floats."
                 )
 
             x = x.squeeze()
@@ -479,11 +485,11 @@ class Linear(AbstractFitFunction):
     _param_names = ("m", "b")
 
     def __str__(self):
-        return f"f(x) = m x + b"
+        return "f(x) = m x + b"
 
     @property
     def latex_str(self) -> str:
-        return fr"m x + b"
+        return r"m x + b"
 
     def func(self, x, m, b):
         """
@@ -594,7 +600,7 @@ class Linear(AbstractFitFunction):
 
         if m == 0.0:
             warn(
-                f"Slope of Linear fit function is zero so no finite root exists. ",
+                "Slope of Linear fit function is zero so no finite root exists. ",
                 RuntimeWarning,
             )
             return _RootResults(np.nan, np.nan)
@@ -668,11 +674,11 @@ class Exponential(AbstractFitFunction):
     _param_names = ("a", "alpha")
 
     def __str__(self):
-        return f"f(x) = a exp(alpha x)"
+        return "f(x) = a exp(alpha x)"
 
     @property
     def latex_str(self) -> str:
-        return fr"a \, \exp(\alpha x)"
+        return r"a \, \exp(\alpha x)"
 
     def func(self, x, a, alpha):
         """
@@ -799,7 +805,9 @@ class ExponentialPlusLinear(AbstractFitFunction):
     _param_names = ("a", "alpha", "m", "b")
 
     def __init__(
-        self, params: Tuple[float, ...] = None, param_errors: Tuple[float, ...] = None,
+        self,
+        params: Tuple[float, ...] = None,
+        param_errors: Tuple[float, ...] = None,
     ):
         self._exponential = Exponential()
         self._linear = Linear()
@@ -937,17 +945,19 @@ class ExponentialPlusOffset(AbstractFitFunction):
     _param_names = ("a", "alpha", "b")
 
     def __init__(
-        self, params: Tuple[float, ...] = None, param_errors: Tuple[float, ...] = None,
+        self,
+        params: Tuple[float, ...] = None,
+        param_errors: Tuple[float, ...] = None,
     ):
         self._explin = ExponentialPlusLinear()
         super().__init__(params=params, param_errors=param_errors)
 
     def __str__(self):
-        return f"f(x) = a exp(alpha x) + b"
+        return "f(x) = a exp(alpha x) + b"
 
     @property
     def latex_str(self) -> str:
-        return fr"a \, \exp(\alpha x) + b"
+        return r"a \, \exp(\alpha x) + b"
 
     @AbstractFitFunction.params.setter
     def params(self, val) -> None:
