@@ -1,19 +1,16 @@
 """
 The `~plasmapy.dispersion` subpackage contains functionality associated with
-plasma dispersion relations, solvers and analytical solutions.
+plasma dispersion relations, including numerical solvers and
+`~plasmapy.dispersion.analytical` solutions.
 """
 __all__ = [
     "plasma_dispersion_func",
     "plasma_dispersion_func_deriv",
-    "tfds_",
-    "two_fluid_dispersion_solution",
 ]
-
+# TODO: import plasmapy.dispersion.numerical once it is populated with
+#       functionality (i.e. expose to namespace)
+from plasmapy.dispersion import analytical
 from plasmapy.dispersion.dispersionfunction import (
     plasma_dispersion_func,
     plasma_dispersion_func_deriv,
 )
-from plasmapy.dispersion.two_fluid_dispersion import (
-    tfds_,
-    two_fluid_dispersion_solution,
-)
