@@ -39,27 +39,26 @@ bound on the losses / transport encountered in a plasma.
 Transport Variables
 ===================
 For documentation on the individual transport variables, please take
-the following links to documentation of methods of `ClassicalTransport`.
-
-* `Resistivity <ClassicalTransport.resistivity>`_
-* `Thermoelectric conductivity <ClassicalTransport.thermoelectric_conductivity>`_
-* `Ion thermal conductivity <ClassicalTransport.ion_thermal_conductivity>`_
-* `Electron thermal conductivity <ClassicalTransport.electron_thermal_conductivity>`_
-* `Ion viscosity <ClassicalTransport.ion_viscosity>`_
-* `Electron viscosity <ClassicalTransport.electron_viscosity>`_
+the following links to documentation of methods of |ClassicalTransport|.
 
+* `~plasmapy.formulary.braginskii.ClassicalTransport.resistivity`
+* `~plasmapy.formulary.braginskii.ClassicalTransport.thermoelectric_conductivity`
+* `~plasmapy.formulary.braginskii.ClassicalTransport.ion_thermal_conductivity`
+* `~plasmapy.formulary.braginskii.ClassicalTransport.electron_thermal_conductivity`
+* `~plasmapy.formulary.braginskii.ClassicalTransport.ion_viscosity`
+* `~plasmapy.formulary.braginskii.ClassicalTransport.electron_viscosity`
 
 Using the module
 ================
 Given that many of the transport variables share a lot of the same computation
 and many are often needed to be calculated simultaneously, this module provides
-a `ClassicalTransport` class that can be initialized once with all of the
+a |ClassicalTransport| class that can be initialized once with all of the
 variables necessary for calculation. It then provides all of the functionality
 as methods (please refer to its documentation).
 
 If you only wish to calculate a single transport variable (or if just don't
 like object oriented interfaces), we have also provided wrapper functions in
-the main module namespace that use `ClassicalTransport` under the hood (see below,
+the main module namespace that use |ClassicalTransport| under the hood (see below,
 in the Functions section).
 
 .. warning::
