@@ -6,8 +6,9 @@ __all__ = [
     "standard_atomic_weight",
     "particle_mass",
     "isotopic_abundance",
-    "integer_charge",
+    "charge_number",
     "electric_charge",
+    "integer_charge",
     "is_stable",
     "half_life",
     "known_isotopes",
@@ -37,6 +38,8 @@ from plasmapy.particles.exceptions import (
 from plasmapy.particles.isotopes import _isotopes
 from plasmapy.particles.particle_class import Particle
 from plasmapy.particles.symbols import atomic_symbol
+from plasmapy.utils.decorators.deprecation import deprecated
+from plasmapy.utils.exceptions import PlasmaPyFutureWarning
 
 __all__.sort()
 
@@ -48,9 +51,9 @@ def atomic_number(element: Particle) -> Integral:
 
     Parameters
     ----------
-    element: `str` or `~plasmapy.particles.Particle`
+    element: `str` or `~plasmapy.particles.particle_class.Particle`
         A string representing an element, isotope, or ion; or an
-        instance of the `~plasmapy.particles.Particle` class.
+        instance of the `~plasmapy.particles.particle_class.Particle` class.
 
     Returns
     -------
@@ -94,9 +97,9 @@ def mass_number(isotope: Particle) -> Integral:
 
     Parameters
     ----------
-    isotope : `str` or `~plasmapy.particles.Particle`
+    isotope : `str` or `~plasmapy.particles.particle_class.Particle`
         A string representing an isotope or a neutron; or an instance of
-        the `plasmapy.particles.Particle` class.
+        the `plasmapy.particles.particle_class.Particle` class.
 
     Returns
     -------
@@ -141,7 +144,7 @@ def standard_atomic_weight(element: Particle) -> u.Quantity:
 
     Parameters
     ----------
-    element: `str`, `int`, or `~plasmapy.particles.Particle`
+    element: `str`, `int`, or `~plasmapy.particles.particle_class.Particle`
         A string representing an element or an integer representing an
         atomic number, or an instance of the Particle class.
 
@@ -202,7 +205,7 @@ def particle_mass(
 
     Parameters
     ----------
-    particle: `str`, `int`, or `~plasmapy.particles.Particle`
+    particle: `str`, `int`, or `~plasmapy.particles.particle_class.Particle`
         A string representing an element, isotope, ion, or special
         particle; an integer representing an atomic number; or an
         instance of the Particle class.
@@ -299,8 +302,8 @@ def isotopic_abundance(isotope: Particle, mass_numb: Optional[Integral] = None)
 
 
 @particle_input(any_of={"charged", "uncharged"})
-def integer_charge(particle: Particle) -> Integral:
-    """Return the integer charge of a particle.
+def charge_number(particle: Particle) -> Integral:
+    """Return the charge number of a particle.
 
     Parameters
     ----------
@@ -322,17 +325,17 @@ def integer_charge(particle: Particle) -> Integral:
         If charge information for the particle is not available.
 
     `~plasmapy.particles.exceptions.AtomicWarning`
-        If the input represents an ion with an integer charge that is
+        If the input represents an ion with a charge number that is
         less than or equal to ``-3``, which is unlikely to occur in
         nature.
 
     Notes
     -----
-    This function supports two formats for integer charge information.
+    This function supports two formats for charge number information.
 
     The first format is a string that has information for the element
-    or isotope at the beginning, a space in between, and the integer
-    charge information in the form of an integer followed by a plus or
+    or isotope at the beginning, a space in between, and the charge
+    number information in the form of an integer followed by a plus or
     minus sign, or a plus or minus sign followed by an integer.
 
     The second format is a string containing element information at
@@ -340,16 +343,30 @@ def integer_charge(particle: Particle) -> Integral:
 
     Examples
     --------
-    >>> integer_charge('Fe-56 2+')
+    >>> charge_number('Fe-56 2+')
     2
-    >>> integer_charge('He -2')
+    >>> charge_number('He -2')
     -2
-    >>> integer_charge('H+')
+    >>> charge_number('H+')
     1
-    >>> integer_charge('N-14++')
+    >>> charge_number('N-14++')
     2
     """
-    return particle.integer_charge
+    return particle.charge_number
+
+
+@deprecated(
+    since="0.7.0",
+    warning_type=PlasmaPyFutureWarning,
+    message=(
+        "integer_charge has been deprecated and will be removed in a "
+        "future release.  Use charge_number instead."
+    ),
+)
+@particle_input(any_of={"charged", "uncharged"})
+def integer_charge(particle: Particle):
+    """Return the charge number of the particle."""
+    return charge_number(particle)
 
 
 @particle_input(any_of={"charged", "uncharged"})
@@ -378,16 +395,16 @@ def electric_charge(particle: Particle) -> u.C:
         If charge information for the particle is not available.
 
     `~plasmapy.particles.exceptions.ParticleWarning`
-        If the input represents an ion with an integer charge that is
+        If the input represents an ion with a charge number that is
         below ``-3``.
 
     Notes
     -----
-    This function supports two formats for integer charge information.
+    This function supports two formats for charge number information.
 
     The first format is a string that has information for the element
-    or isotope at the beginning, a space in between, and the integer
-    charge information in the form of an integer followed by a plus or
+    or isotope at the beginning, a space in between, and the charge
+    number information in the form of an integer followed by a plus or
     minus sign, or a plus or minus sign followed by an integer.
 
     The second format is a string containing element information at
@@ -414,7 +431,7 @@ def is_stable(particle: Particle, mass_numb: Optional[Integral] = None) -> bool:
 
     Parameters
     ----------
-    particle: `int`, `str`, or `~plasmapy.particles.Particle`
+    particle: `int`, `str`, or `~plasmapy.particles.particle_class.Particle`
         A string representing an isotope or particle, or an integer
         representing an atomic number.
 
@@ -467,7 +484,7 @@ def half_life(particle: Particle, mass_numb: Optional[Integral] = None) -> u.Qua
 
     Parameters
     ----------
-    particle: `int`, `str`, or `~plasmapy.particles.Particle`
+    particle: `int`, `str`, or `~plasmapy.particles.particle_class.Particle`
         A string representing an isotope or particle, an integer
         representing an atomic number, or an instance of the Particle
         class.
@@ -830,11 +847,11 @@ def reduced_mass(test_particle, target_particle) -> u.Quantity:
 
     Parameters
     ----------
-    test_particle, target_particle : `str`, `int`, `~plasmapy.particles.Particle`,
+    test_particle, target_particle : `str`, `int`, `~plasmapy.particles.particle_class.Particle`,
     `~astropy.units.Quantity`, or `~astropy.constants.Constant`
 
         The test particle as represented by a string, an integer
-        representing atomic number, a `~plasmapy.particles.Particle`
+        representing atomic number, a `~plasmapy.particles.particle_class.Particle`
         object, or a `~astropy.units.Quantity` or
         `~astropy.constants.Constant` with units of mass.
 
@@ -857,11 +874,11 @@ def reduced_mass(test_particle, target_particle) -> u.Quantity:
 
     `TypeError`
         If either argument is not a `str`, `int`,
-        `~plasmapy.particles.Particle`, `~astropy.units.Quantity`, or
-        `~astropy.constants.Constant`.
+        `~plasmapy.particles.particle_class.Particle`,
+        `~astropy.units.Quantity`, or `~astropy.constants.Constant`.
 
-    Example
-    -------
+    Examples
+    --------
     >>> from astropy import units as u
     >>> reduced_mass('p+', 'e-')
     <Quantity 9.104425e-31 kg>
@@ -887,7 +904,7 @@ def reduced_mass(test_particle, target_particle) -> u.Quantity:
                 particle = Particle(particle)
             return particle.mass.to(u.kg)
         except u.UnitConversionError as exc1:
-            raise u.UnitConversionError(f"Incorrect units in reduced_mass.") from exc1
+            raise u.UnitConversionError("Incorrect units in reduced_mass.") from exc1
         except MissingParticleDataError:
             raise MissingParticleDataError(
                 f"Unable to find the reduced mass because the mass of "
