@@ -2,7 +2,7 @@
 Module for loading atomic data for elements from
 :file:`plasmapy/particles/data/elements.json`.
 
-The periodic tabla data is from: http://periodic.lanl.gov/index.shtml
+The periodic tabla data is from: https://periodic.lanl.gov/index.shtml
 
 .. attention::
     This module is not part of PlasmaPy's public API.
@@ -10,13 +10,18 @@ The periodic tabla data is from: http://periodic.lanl.gov/index.shtml
 __all__ = []
 
 import astropy.units as u
-import collections
 import json
 import pkgutil
 
-_PeriodicTable = collections.namedtuple(
-    "periodic_table", ["group", "category", "block", "period"]
-)
+from dataclasses import dataclass
+
+
+@dataclass
+class _PeriodicTable:
+    group: int
+    period: int
+    block: str
+    category: str
 
 
 def _element_obj_hook(obj):
