@@ -3,7 +3,7 @@ Objects for storing ionization state data for a single element or for
 a single ionization level.
 """
 
-__all__ = ["IonizationState", "IonicLevel"]
+__all__ = ["IonicLevel", "IonizationState"]
 
 import numpy as np
 import warnings
@@ -18,8 +18,11 @@ from plasmapy.particles.exceptions import (
     InvalidParticleError,
     ParticleError,
 )
-from plasmapy.particles.particle_class import Particle
+from plasmapy.particles.particle_class import CustomParticle, Particle
+from plasmapy.particles.particle_collections import ionic_levels, ParticleList
 from plasmapy.utils.decorators import validate_quantities
+from plasmapy.utils.decorators.deprecation import deprecated
+from plasmapy.utils.exceptions import PlasmaPyFutureWarning
 
 _number_density_errmsg = (
     "Number densities must be Quantity objects with units of inverse volume."
@@ -52,7 +55,7 @@ class IonicLevel:
     >>> alpha_fraction = IonicLevel("alpha", ionic_fraction=0.31)
     >>> alpha_fraction.ionic_symbol
     'He-4 2+'
-    >>> alpha_fraction.integer_charge
+    >>> alpha_fraction.charge_number
     2
     >>> alpha_fraction.ionic_fraction
     0.31
@@ -65,11 +68,15 @@ class IonicLevel:
                 return False
 
             ionic_fraction_within_tolerance = np.isclose(
-                self.ionic_fraction, other.ionic_fraction, rtol=1e-15,
+                self.ionic_fraction,
+                other.ionic_fraction,
+                rtol=1e-15,
             )
 
             number_density_within_tolerance = u.isclose(
-                self.number_density, other.number_density, rtol=1e-15,
+                self.number_density,
+                other.number_density,
+                rtol=1e-15,
             )
 
             return all(
@@ -84,12 +91,14 @@ class IonicLevel:
             ) from exc
 
     @particle_input
-    def __init__(self, ion: Particle, ionic_fraction=None, number_density=None):
+    def __init__(
+        self, ion: Particle, ionic_fraction=None, number_density=None, T_i=None
+    ):
         try:
             self.ion = ion
             self.ionic_fraction = ionic_fraction
             self.number_density = number_density
-
+            self.T_i = T_i
         except Exception as exc:
             raise ParticleError("Unable to create IonicLevel object") from exc
 
@@ -105,9 +114,24 @@ class IonicLevel:
         return self.ion.ionic_symbol
 
     @property
+    def charge_number(self) -> Integral:
+        """The charge number of the ion."""
+        return self.ion.charge_number
+
+    @property
+    @deprecated(
+        since="0.7.0",
+        name="integer_charge",
+        message=(
+            "The integer_charge attribute of IonicLevel has been "
+            "deprecated and will be removed in a future release.  Use "
+            "charge_number instead."
+        ),
+        warning_type=PlasmaPyFutureWarning,
+    )
     def integer_charge(self) -> Integral:
-        """The integer charge of the ion."""
-        return self.ion.integer_charge
+        """The charge number of the ion."""
+        return self.charge_number
 
     @property
     def ionic_fraction(self) -> Real:
@@ -135,7 +159,7 @@ class IonicLevel:
                 raise TypeError(f"Invalid ionic fraction: {ionfrac}")
             else:
                 if out_of_range:
-                    raise ValueError(f"The ionic fraction must be between 0 and 1.")
+                    raise ValueError("The ionic fraction must be between 0 and 1.")
                 else:
                     self._ionic_fraction = ionfrac
 
@@ -154,6 +178,18 @@ class IonicLevel:
         else:
             self._number_density = n
 
+    @property
+    def T_i(self) -> u.K:
+        """The ion temperature of this particular charge state."""
+        return self._T_i
+
+    @T_i.setter
+    @validate_quantities(
+        T={"can_be_negative": False, "can_be_inf": False, "none_shall_pass": True},
+    )
+    def T_i(self, T: u.K):
+        self._T_i = np.nan * u.K if T is None else T
+
 
 class IonizationState:
     """
@@ -163,13 +199,13 @@ class IonizationState:
     Parameters
     ----------
     particle: `~plasmapy.particles.particle_class.ParticleLike`
-        A `str` or `~plasmapy.particles.Particle` instance representing
-        an element, isotope, or ion; or an integer representing the
-        atomic number of an element.
+        A `str` or `~plasmapy.particles.particle_class.Particle` instance
+        representing an element, isotope, or ion; or an integer representing
+        the atomic number of an element.
 
     ionic_fractions: `~numpy.ndarray`, `list`, `tuple`, or `~astropy.units.Quantity`; optional
         The ionization fractions of an element, where the indices
-        correspond to integer charge.  This argument should contain the
+        correspond to the charge number.  This argument should contain the
         atomic number plus one items, and must sum to one within an
         absolute tolerance of ``tol`` if dimensionless.  Alternatively,
         this argument may be a `~astropy.units.Quantity` that represents
@@ -184,12 +220,13 @@ class IonizationState:
         ions.
 
     tol: `float` or integer, keyword-only, optional
-        The absolute tolerance used by `~numpy.isclose` when testing
-        normalizations and making comparisons.  Defaults to ``1e-15``.
+        The absolute tolerance used by `~numpy.isclose` and similar
+        functions when testing normalizations and making comparisons.
+        Defaults to ``1e-15``.
 
     Raises
     ------
-    `~plasmapy.particles.exceptions..ParticleError`
+    `~plasmapy.particles.exceptions.ParticleError`
         If the ionic fractions are not normalized or contain invalid
         values, or if number density information is provided through
         both ``ionic_fractions`` and ``n_elem``.
@@ -231,7 +268,14 @@ class IonizationState:
 
     # TODO: Add in functionality to find equilibrium ionization states.
 
-    @validate_quantities(T_e={"unit": u.K, "equivalencies": u.temperature_energy()})
+    @validate_quantities(
+        T_e={"unit": u.K, "equivalencies": u.temperature_energy()},
+        T_i={
+            "unit": u.K,
+            "equivalencies": u.temperature_energy(),
+            "none_shall_pass": True,
+        },
+    )
     @particle_input(require="element")
     def __init__(
         self,
@@ -239,16 +283,21 @@ class IonizationState:
         ionic_fractions=None,
         *,
         T_e: u.K = np.nan * u.K,
+        T_i: u.K = None,
         kappa: Real = np.inf,
         n_elem: u.m ** -3 = np.nan * u.m ** -3,
         tol: Union[float, int] = 1e-15,
     ):
-        """Initialize an `~plasmapy.particles.IonizationState` instance."""
+        """
+        Initialize an `~plasmapy.particles.ionization_state.IonizationState`
+        instance.
+        """
+        self._number_of_particles = particle.atomic_number + 1
 
         if particle.is_ion or particle.is_category(require=("uncharged", "element")):
             if ionic_fractions is None:
-                ionic_fractions = np.zeros(particle.atomic_number + 1)
-                ionic_fractions[particle.integer_charge] = 1.0
+                ionic_fractions = np.zeros(self._number_of_particles)
+                ionic_fractions[particle.charge_number] = 1.0
                 particle = Particle(
                     particle.isotope if particle.isotope else particle.element
                 )
@@ -263,6 +312,7 @@ class IonizationState:
         try:
             self.tol = tol
             self.T_e = T_e
+            self.T_i = T_i
             self.kappa = kappa
 
             if (
@@ -296,16 +346,25 @@ class IonizationState:
     def __repr__(self) -> str:
         return self.__str__()
 
-    def __getitem__(self, value) -> IonicLevel:
+    def __getitem__(self, value) -> List[IonicLevel]:
         """Return information for a single ionization level."""
         if isinstance(value, slice):
-            raise TypeError("IonizationState instances cannot be sliced.")
+            return [
+                IonicLevel(
+                    ion=Particle(self.base_particle, Z=val),
+                    ionic_fraction=self.ionic_fractions[val],
+                    number_density=self.number_densities[val],
+                    T_i=self.T_i[val],
+                )
+                for val in range(0, self._number_of_particles)[value]
+            ]
 
         if isinstance(value, Integral) and 0 <= value <= self.atomic_number:
             result = IonicLevel(
                 ion=Particle(self.base_particle, Z=value),
                 ionic_fraction=self.ionic_fractions[value],
                 number_density=self.number_densities[value],
+                T_i=self.T_i[value],
             )
         else:
             if not isinstance(value, Particle):
@@ -313,7 +372,7 @@ class IonizationState:
                     value = Particle(value)
                 except InvalidParticleError as exc:
                     raise InvalidParticleError(
-                        f"{value} is not a valid integer charge or particle."
+                        f"{value} is not a valid charge number or particle."
                     ) from exc
 
             same_element = value.element == self.element
@@ -321,17 +380,18 @@ class IonizationState:
             has_charge_info = value.is_category(any_of=["charged", "uncharged"])
 
             if same_element and same_isotope and has_charge_info:
-                Z = value.integer_charge
+                Z = value.charge_number
                 result = IonicLevel(
                     ion=Particle(self.base_particle, Z=Z),
                     ionic_fraction=self.ionic_fractions[Z],
                     number_density=self.number_densities[Z],
+                    T_i=self.T_i[Z],
                 )
             else:
                 if not same_element or not same_isotope:
                     raise ParticleError("Inconsistent element or isotope.")
                 elif not has_charge_info:
-                    raise ChargeError("No integer charge provided.")
+                    raise ChargeError("No charge number provided.")
         return result
 
     def __setitem__(self, key, value):
@@ -354,7 +414,7 @@ class IonizationState:
         Raises
         ------
         `TypeError`
-            If ``other`` is not an `~plasmapy.particles.IonizationState`
+            If ``other`` is not an `~plasmapy.particles.ionization_state.IonizationState`
             instance.
 
         `ParticleError`
@@ -378,11 +438,7 @@ class IonizationState:
         same_isotope = self.isotope == other.isotope
 
         if not same_element or not same_isotope:
-            raise ParticleError(
-                "An instance of the IonizationState class may only be "
-                "compared with another IonizationState instance if "
-                "both correspond to the same element and/or isotope."
-            )
+            return False
 
         # Use the tighter of the two tolerances. For thermodynamic
         # quantities, use it as a relative tolerance because the values
@@ -393,15 +449,13 @@ class IonizationState:
         same_T_e = (
             np.isnan(self.T_e)
             and np.isnan(other.T_e)
-            or u.allclose(self.T_e, other.T_e, rtol=min_tol * u.K, atol=0 * u.K)
+            or u.allclose(self.T_e, other.T_e, rtol=min_tol, atol=0 * u.K)
         )
 
         same_n_elem = (
             np.isnan(self.n_elem)
             and np.isnan(other.n_elem)
-            or u.allclose(
-                self.n_elem, other.n_elem, rtol=min_tol * u.m ** -3, atol=0 * u.m ** -3
-            )
+            or u.allclose(self.n_elem, other.n_elem, rtol=min_tol, atol=0 * u.m ** -3)
         )
 
         # For the next line, recall that np.nan == np.nan is False
@@ -423,8 +477,8 @@ class IonizationState:
     @property
     def ionic_fractions(self) -> np.ndarray:
         """
-        Return the ionic fractions, where the index corresponds to
-        the integer charge.
+        The ionic fractions, where the index corresponds to the charge
+        number.
 
         Examples
         --------
@@ -482,8 +536,8 @@ class IonizationState:
 
     def _is_normalized(self, tol: Optional[Real] = None) -> bool:
         """
-        Return `True` if the sum of the ionization fractions is equal to
-        one within the allowed tolerance, and `False` otherwise.
+        `True` if the sum of the ionization fractions is equal to
+        ``1`` within the allowed tolerance, and `False` otherwise.
         """
         tol = tol if tol is not None else self.tol
         if not isinstance(tol, Real):
@@ -507,15 +561,14 @@ class IonizationState:
     @validate_quantities
     def n_e(self) -> u.m ** -3:
         """
-        Return the electron number density assuming a single species
-        plasma.
+        The electron number density assuming a single species plasma.
         """
-        return np.sum(self._n_elem * self.ionic_fractions * self.integer_charges)
+        return np.sum(self._n_elem * self.ionic_fractions * self.charge_numbers)
 
     @property
     @validate_quantities
     def n_elem(self) -> u.m ** -3:
-        """Return the total number density of neutrals and all ions."""
+        """The total number density of neutrals and all ions."""
         return self._n_elem.to(u.m ** -3)
 
     @n_elem.setter
@@ -532,7 +585,7 @@ class IonizationState:
     @property
     @validate_quantities
     def number_densities(self) -> u.m ** -3:
-        """Return the number densities for each state."""
+        """The number densities for each state."""
         try:
             return (self.n_elem * self.ionic_fractions).to(u.m ** -3)
         except Exception:
@@ -555,7 +608,7 @@ class IonizationState:
 
     @property
     def T_e(self) -> u.K:
-        """Return the electron temperature."""
+        """The electron temperature."""
         if self._T_e is None:
             raise ParticleError("No electron temperature has been specified.")
         return self._T_e.to(u.K, equivalencies=u.temperature_energy())
@@ -573,14 +626,54 @@ class IonizationState:
                 raise ParticleError("T_e cannot be negative.")
         self._T_e = value
 
+    @property
+    @validate_quantities(
+        validations_on_return=dict(
+            equivalencies=u.temperature_energy(),
+        )
+    )
+    def T_i(self) -> u.K:
+        """
+        The ion temperature. If the ion temperature has not been provided,
+        then this attribute will provide the electron temperature.
+        """
+        return self._T_i
+
+    @T_i.setter
+    @validate_quantities(
+        value=dict(
+            equivalencies=u.temperature_energy(),
+            none_shall_pass=True,
+            can_be_negative=False,
+        )
+    )
+    def T_i(self, value: u.K):
+        """Set the ion temperature."""
+        if value is None:
+            self._T_i = np.repeat(self._T_e, self._number_of_particles)
+            return
+
+        if value.size == 1:
+            self._T_i = np.repeat(value, self._number_of_particles)
+        elif value.size == self._number_of_particles:
+            self._T_i = value
+        else:
+            error_str = (
+                "T_i must be set with either one common temperature"
+                f" for all ions, or a set of {self._number_of_particles} of them. "
+            )
+
+            if value.size == 5 and self._number_of_particles != 5:
+                error_str += f" For {self.base_particle}, five is right out."
+            raise ParticleError(error_str)
+
     @property
     def kappa(self) -> np.real:
         """
-        Return the kappa parameter for a kappa distribution function
-        for electrons.
+        The κ parameter for a kappa distribution function for electrons.
 
         The value of ``kappa`` must be greater than ``1.5`` in order to
-        have a valid distribution function.  If ``kappa`` equals
+        have a valid distribution function.  If ``kappa`` is
         `~numpy.inf`, then the distribution function reduces to a
         Maxwellian.
 
@@ -602,69 +695,81 @@ class IonizationState:
 
     @property
     def element(self) -> str:
-        """Return the atomic symbol of the element."""
+        """The atomic symbol of the element."""
         return self._particle.element
 
     @property
     def isotope(self) -> Optional[str]:
         """
-        Return the isotope symbol for an isotope, or `None` if the
-        particle is not an isotope.
+        The isotope symbol for an isotope, or `None` if the particle is
+        not an isotope.
         """
         return self._particle.isotope
 
     @property
     def base_particle(self) -> str:
-        """Return the symbol of the element or isotope."""
+        """The symbol of the element or isotope."""
         return self.isotope if self.isotope else self.element
 
+    def to_list(self) -> ParticleList:
+        """
+        Return a `~plasmapy.particles.particle_collections.ParticleList`
+        of the ionic levels.
+        """
+        return ionic_levels(self.base_particle)
+
     @property
     def atomic_number(self) -> int:
-        """Return the atomic number of the element."""
+        """The atomic number of the element."""
         return self._particle.atomic_number
 
-    @property
-    def _particle_instances(self) -> List[Particle]:
-        """
-        Return a list of the `~plasmapy.particles.Particle` class
-        instances corresponding to each ion.
-        """
-        return [
-            Particle(self._particle.symbol, Z=i) for i in range(self.atomic_number + 1)
-        ]
+    def __len__(self):
+        return self._number_of_particles
 
     @property
     def ionic_symbols(self) -> List[str]:
-        """Return the ionic symbols for all charge states."""
-        return [particle.ionic_symbol for particle in self._particle_instances]
+        """The ionic symbols for all charge states."""
+        return self.to_list().symbols
 
     @property
+    def charge_numbers(self) -> np.ndarray:
+        """An array of the charge numbers."""
+        return self.to_list().charge_number
+
+    @property
+    @deprecated(
+        since="0.7.0",
+        name="integer_charges",
+        message=(
+            "The integer_charges attribute of IonizationState has been "
+            "deprecated and will be removed in a future release.  Use "
+            "charge_numbers instead."
+        ),
+        warning_type=PlasmaPyFutureWarning,
+    )
     def integer_charges(self) -> np.ndarray:
-        """Return an array with the integer charges."""
-        return np.arange(0, self.atomic_number + 1, dtype=int)
+        """An array of the charge numbers."""
+        return self.charge_numbers
 
     @property
     def Z_mean(self) -> np.float64:
-        """Return the mean integer charge"""
+        """Return the mean charge number."""
         if np.nan in self.ionic_fractions:
             raise ChargeError(
                 "Z_mean cannot be found because no ionic fraction "
                 f"information is available for {self.base_particle}."
             )
-        return np.sum(self.ionic_fractions * np.arange(self.atomic_number + 1))
+        return np.sum(self.ionic_fractions * self.charge_numbers)
 
     @property
     def Z_rms(self) -> np.float64:
-        """Return the root mean square integer charge."""
-        return np.sqrt(
-            np.sum(self.ionic_fractions * np.arange(self.atomic_number + 1) ** 2)
-        )
+        """The root mean square charge number."""
+        return np.sqrt(np.sum(self.ionic_fractions * self.charge_numbers ** 2))
 
     @property
     def Z_most_abundant(self) -> List[Integral]:
         """
-        Return a `list` of the integer charges with the highest ionic
-        fractions.
+        A `list` of the charge numbers with the highest ionic fractions.
 
         Examples
         --------
@@ -674,7 +779,6 @@ class IonizationState:
         >>> Li = IonizationState('Li', [0.4, 0.4, 0.2, 0.0])
         >>> Li.Z_most_abundant
         [0, 1]
-
         """
         if np.any(np.isnan(self.ionic_fractions)):
             raise ParticleError(
@@ -688,7 +792,14 @@ class IonizationState:
 
     @property
     def tol(self) -> Real:
-        """Return the absolute tolerance for comparisons."""
+        """
+        The absolute tolerance for comparisons.
+
+        This attribute is used as the ``atol`` parameter in
+        `numpy.isclose`, `numpy.allclose`,
+        `astropy.units.isclose`, and `astropy.units.allclose`
+        when testing normalizations and making comparisons.
+        """
         return self._tol
 
     @tol.setter
@@ -704,7 +815,7 @@ class IonizationState:
     def _get_states_info(self, minimum_ionic_fraction=0.01) -> List[str]:
         """
         Return a `list` containing the ion symbol, ionic fraction, and
-        (if available) the number density for that ion.
+        (if available) the number density and temperature for that ion.
 
         Parameters
         ----------
@@ -718,24 +829,84 @@ class IonizationState:
             if state.ionic_fraction >= minimum_ionic_fraction:
                 state_info = ""
                 symbol = state.ionic_symbol
-                if state.integer_charge < 10:
-                    symbol = symbol[:-2] + " " + symbol[-2:]
-                fraction = "{:.3f}".format(state.ionic_fraction)
+                if state.charge_number < 10:
+                    symbol = f"{symbol[:-2]} {symbol[-2:]}"
+                fraction = f"{state.ionic_fraction:.3f}"
 
                 state_info += f"{symbol}: {fraction}"
 
                 if np.isfinite(self.n_elem):
-                    value = "{:.2e}".format(state.number_density.si.value)
+                    value = f"{state.number_density.si.value:.2e}"
                     state_info += f"    n_i = {value} m**-3"
 
+                if np.isfinite(state.T_i):
+                    value = f"{state.T_i.si.value:.2e}"
+                    state_info += f"    T_i = {value} K"
+
                 states_info.append(state_info)
 
         return states_info
 
+    def average_ion(
+        self,
+        *,
+        include_neutrals: bool = True,
+        use_rms_charge: bool = False,
+        use_rms_mass: bool = False,
+    ) -> CustomParticle:
+        """
+        Return a |CustomParticle| instance representing the average
+        particle in this ionization state.
+
+        By default, the weighted mean will be used as the average, with
+        the ionic fractions as the weights. If ``use_rms_charge`` or
+        ``use_rms_mass`` is `True`, then this method will return the root
+        mean square of the charge or mass, respectively.
+
+        Parameters
+        ----------
+        include_neutrals : `bool`, optional, keyword-only
+            If `True`, include neutrals when calculating the mean values
+            of the different particles.  If `False`, exclude neutrals.
+            Defaults to `True`.
+
+        use_rms_charge : `bool`, optional, keyword-only
+            If `True`, use the root mean square charge instead of the
+            mean charge. Defaults to `False`.
+
+        use_rms_mass : `bool`, optional, keyword-only
+            If `True`, use the root mean square mass instead of the mean
+            mass. Defaults to `False`.
+
+        Returns
+        -------
+        ~plasmapy.particles.particle_class.CustomParticle
+
+        Examples
+        --------
+        >>> state = IonizationState("He", [0.1, 0.9, 0.0])
+        >>> state.average_ion()
+        CustomParticle(mass=6.645657...e-27 kg, charge=1.44...e-19 C)
+        >>> state.average_ion(include_neutrals=False)
+        CustomParticle(mass=6.6455660...e-27 kg, charge=1.602...e-19 C)
+        >>> state.average_ion(use_rms_charge=True, use_rms_mass=True)
+        CustomParticle(mass=6.645657...e-27 kg, charge=1.519958...e-19 C)
+        """
+        min_charge = 0 if include_neutrals else 1
+
+        particle_list = self.to_list()[min_charge:]
+        abundances = self.ionic_fractions[min_charge:]
+
+        return particle_list.average_particle(
+            abundances=abundances,
+            use_rms_charge=use_rms_charge,
+            use_rms_mass=use_rms_mass,
+        )
+
     def summarize(self, minimum_ionic_fraction: Real = 0.01) -> None:
         """
         Print quicklook information for an
-        `~plasmapy.particles.IonizationState` instance.
+        `~plasmapy.particles.ionization_state.IonizationState` instance.
 
         Parameters
         ----------
@@ -744,8 +915,8 @@ class IonizationState:
             below this level, then information for it will not be
             printed.  Defaults to 0.01.
 
-        Example
-        -------
+        Examples
+        --------
         >>> He_states = IonizationState(
         ...     'He',
         ...     [0.941, 0.058, 0.001],
@@ -756,8 +927,8 @@ class IonizationState:
         >>> He_states.summarize()
         IonizationState instance for He with Z_mean = 0.06
         ----------------------------------------------------------------
-        He  0+: 0.941    n_i = 5.18e+19 m**-3
-        He  1+: 0.058    n_i = 3.20e+18 m**-3
+        He  0+: 0.941    n_i = 5.18e+19 m**-3    T_i = 5.34e+00 K
+        He  1+: 0.058    n_i = 3.20e+18 m**-3    T_i = 5.34e+00 K
         ----------------------------------------------------------------
         n_elem = 5.51e+19 m**-3
         n_e = 3.31e+18 m**-3
@@ -768,17 +939,8 @@ class IonizationState:
         """
         separator_line = [64 * "-"]
 
-        scientific = "{:.2e}"
-        floaty = "{:.2f}"
-
-        n_elem = scientific.format(self.n_elem.value)
-        n_e = scientific.format(self.n_e.value)
-        T_e = scientific.format(self.T_e.value)
-        kappa = floaty.format(self.kappa)
-        Z_mean = floaty.format(self.Z_mean)
-
         output = [
-            f"IonizationState instance for {self.base_particle} with Z_mean = {Z_mean}"
+            f"IonizationState instance for {self.base_particle} with Z_mean = {self.Z_mean:.2f}"
         ]
         attributes = []
 
@@ -786,14 +948,15 @@ class IonizationState:
             output += separator_line
             output += self._get_states_info(minimum_ionic_fraction)
             output += separator_line
+            # TODO add T_i somewhere around here, probably
 
         if not np.isnan(self.n_elem):
-            attributes.append(f"n_elem = {n_elem} m**-3")
-            attributes.append(f"n_e = {n_e} m**-3")
+            attributes.append(f"n_elem = {self.n_elem.value:.2e} m**-3")
+            attributes.append(f"n_e = {self.n_e.value:.2e} m**-3")
         if not np.isnan(self.T_e):
-            attributes.append(f"T_e = {T_e} K")
+            attributes.append(f"T_e = {self.T_e.value:.2f} K")
         if np.isfinite(self.kappa):
-            attributes.append(f"kappa = {kappa}")
+            attributes.append(f"kappa = {self.kappa:.2f}")
 
         if attributes:
             attributes += separator_line
