@@ -5,7 +5,6 @@ isotopes.
 __all__ = ["IonizationStateCollection"]
 
 import astropy.units as u
-import collections
 import numpy as np
 
 from numbers import Integral, Real
@@ -18,7 +17,8 @@ from plasmapy.particles.exceptions import (
     ParticleError,
 )
 from plasmapy.particles.ionization_state import IonicLevel, IonizationState
-from plasmapy.particles.particle_class import Particle, ParticleLike
+from plasmapy.particles.particle_class import CustomParticle, Particle, ParticleLike
+from plasmapy.particles.particle_collections import ParticleList
 from plasmapy.particles.symbols import particle_symbol
 from plasmapy.utils.decorators import validate_quantities
 
@@ -181,6 +181,9 @@ class IonizationStateCollection:
                 "Unable to create IonizationStateCollection object."
             ) from exc
 
+    def __len__(self) -> int:
+        return len(self._base_particles)
+
     def __str__(self) -> str:
         return f"<IonizationStateCollection for: {', '.join(self.base_particles)}>"
 
@@ -357,8 +360,8 @@ class IonizationStateCollection:
         # that np.nan == np.nan is False.
 
         for attribute in ["T_e", "n_e", "kappa"]:
-            this = eval(f"self.{attribute}")
-            that = eval(f"other.{attribute}")
+            this = getattr(self, attribute)
+            that = getattr(other, attribute)
 
             # TODO: Maybe create a function in utils called same_enough
             # TODO: that would take care of all of these disparate
@@ -379,8 +382,8 @@ class IonizationStateCollection:
 
         for attribute in ["ionic_fractions", "number_densities"]:
 
-            this_dict = eval(f"self.{attribute}")
-            that_dict = eval(f"other.{attribute}")
+            this_dict = getattr(self, attribute)
+            that_dict = getattr(other, attribute)
 
             for particle in self.base_particles:
 
@@ -403,8 +406,8 @@ class IonizationStateCollection:
     @property
     def ionic_fractions(self) -> Dict[str, np.array]:
         """
-        Return a `dict` containing the ionic fractions for each element
-        and isotope.
+        A `dict` containing the ionic fractions for each element and
+        isotope.
 
         The keys of this `dict` are the symbols for each element or
         isotope.  The values will be `~numpy.ndarray` objects containing
@@ -652,23 +655,20 @@ class IonizationStateCollection:
     @property
     @validate_quantities
     def n_e(self) -> u.m ** -3:
-        """
-        Return the electron number density under the assumption of
-        quasineutrality.
-        """
+        """The electron number density under the assumption of quasineutrality."""
         number_densities = self.number_densities
         n_e = 0.0 * u.m ** -3
         for elem in self.base_particles:
             atomic_numb = atomic_number(elem)
             number_of_ionization_states = atomic_numb + 1
-            integer_charges = np.linspace(0, atomic_numb, number_of_ionization_states)
-            n_e += np.sum(number_densities[elem] * integer_charges)
+            charge_numbers = np.linspace(0, atomic_numb, number_of_ionization_states)
+            n_e += np.sum(number_densities[elem] * charge_numbers)
         return n_e
 
     @property
     @validate_quantities
     def n0(self) -> u.m ** -3:
-        """Return the number density scaling factor."""
+        """The number density scaling factor."""
         return self._pars["n"]
 
     @n0.setter
@@ -688,8 +688,8 @@ class IonizationStateCollection:
     @property
     def number_densities(self) -> Dict[str, u.Quantity]:
         """
-        Return a `dict` containing the number densities for element or
-        isotope.
+        A `dict` containing the number densities for the elements and/or
+        isotopes composing the collection.
         """
         return {
             elem: self.n0 * self.abundances[elem] * self.ionic_fractions[elem]
@@ -698,7 +698,7 @@ class IonizationStateCollection:
 
     @property
     def abundances(self) -> Optional[Dict[ParticleLike, Real]]:
-        """Return the elemental abundances."""
+        """The elemental abundances."""
         return self._pars["abundances"]
 
     @abundances.setter
@@ -712,9 +712,9 @@ class IonizationStateCollection:
             self._pars["abundances"] = {elem: np.nan for elem in self.base_particles}
         elif not isinstance(abundances_dict, dict):
             raise TypeError(
-                f"The abundances attribute must be a dict with "
-                f"elements or isotopes as keys and real numbers "
-                f"representing relative abundances as values."
+                "The abundances attribute must be a dict with "
+                "elements or isotopes as keys and real numbers "
+                "representing relative abundances as values."
             )
         else:
             old_keys = abundances_dict.keys()
@@ -761,9 +761,8 @@ class IonizationStateCollection:
     @property
     def log_abundances(self) -> Dict[str, Real]:
         """
-        Return a `dict` with atomic or isotope symbols as keys and the
-        base 10 logarithms of the relative abundances as the
-        corresponding values.
+        A `dict` with atomic or isotope symbols as keys and the base 10
+        logarithms of the relative abundances as the corresponding values.
         """
         log_abundances_dict = {}
         for key in self.abundances.keys():
@@ -784,7 +783,7 @@ class IonizationStateCollection:
 
     @property
     def T_e(self) -> u.K:
-        """Return the electron temperature."""
+        """The electron temperature."""
         return self._pars["T_e"]
 
     @T_e.setter
@@ -808,8 +807,7 @@ class IonizationStateCollection:
     @property
     def kappa(self) -> np.real:
         """
-        Return the kappa parameter for a kappa distribution function
-        for electrons.
+        The κ parameter for a kappa distribution function for electrons.
 
         The value of ``kappa`` must be greater than ``1.5`` in order to
         have a valid distribution function.  If ``kappa`` equals
@@ -835,14 +833,14 @@ class IonizationStateCollection:
     @property
     def base_particles(self) -> List[str]:
         """
-        Return a list of the elements and isotopes whose ionization
-        states are being kept track of.
+        A `list` of the elements and isotopes whose ionization states
+        are being kept track of.
         """
         return self._base_particles
 
     @property
     def tol(self) -> np.real:
-        """Return the absolute tolerance for comparisons."""
+        """The absolute tolerance for comparisons."""
         return self._tol
 
     @tol.setter
@@ -855,6 +853,93 @@ class IonizationStateCollection:
         else:
             raise ValueError("Need 0 <= tol <= 1.")
 
+    def average_ion(
+        self,
+        *,
+        include_neutrals: bool = True,
+        use_rms_charge: bool = False,
+        use_rms_mass: bool = False,
+    ) -> CustomParticle:
+        """
+        Return a |CustomParticle| representing the mean particle
+        included across all ionization states.
+
+        By default, this method will use the weighted mean to calculate
+        the properties of the |CustomParticle|, where the weights for
+        each ionic level is given by its ionic fraction multiplied by
+        the abundance of the base element or isotope. If
+        ``use_rms_charge`` or ``use_rms_mass`` is `True`, then this
+        method will return the root mean square of the charge or mass,
+        respectively.
+
+        Parameters
+        ----------
+        include_neutrals : `bool`, optional, keyword-only
+            If `True`, include neutrals when calculating the mean values
+            of the different particles.  If `False`, exclude neutrals.
+            Defaults to `True`.
+
+        use_rms_charge : `bool`, optional, keyword-only
+            If `True`, use the root mean square charge instead of the
+            mean charge. Defaults to `False`.
+
+        use_rms_mass : `bool`, optional, keyword-only
+            If `True`, use the root mean square mass instead of the mean
+            mass. Defaults to `False`.
+
+        Raises
+        ------
+        `~plasmapy.particles.exceptions.ParticleError`
+            If the abundance of any of the elements or isotopes is not
+            defined and the |IonizationStateCollection| instance includes
+            more than one element or isotope.
+
+        Returns
+        -------
+        ~plasmapy.particles.particle_class.CustomParticle
+
+        Examples
+        --------
+        >>> states = IonizationStateCollection(
+        ...     {"H": [0.1, 0.9], "He": [0, 0.1, 0.9]},
+        ...     abundances={"H": 1, "He": 0.1}
+        ... )
+        >>> states.average_ion()
+        CustomParticle(mass=2.12498...e-27 kg, charge=1.5876...e-19 C)
+        >>> states.average_ion(include_neutrals=False, use_rms_charge=True, use_rms_mass=True)
+        CustomParticle(mass=2.633...e-27 kg, charge=1.805...e-19 C)
+        """
+        min_charge = 0 if include_neutrals else 1
+
+        all_particles = ParticleList()
+        all_abundances = []
+
+        for base_particle in self.base_particles:
+
+            ionization_state = self[base_particle]
+            ionic_levels = ionization_state.to_list()[min_charge:]
+            all_particles.extend(ionic_levels)
+
+            base_particle_abundance = self.abundances[base_particle]
+
+            if np.isnan(base_particle_abundance):
+                if len(self) == 1:
+                    base_particle_abundance = 1
+                else:
+                    raise ParticleError(
+                        "Unable to provide an average particle without abundances."
+                    )
+
+            ionic_fractions = ionization_state.ionic_fractions[min_charge:]
+            ionic_abundances = base_particle_abundance * ionic_fractions
+            all_abundances.extend(ionic_abundances)
+
+        return all_particles.average_particle(
+            use_rms_charge=use_rms_charge,
+            use_rms_mass=use_rms_mass,
+            abundances=all_abundances,
+        )
+
     def summarize(self, minimum_ionic_fraction: Real = 0.01) -> None:
         """
         Print quicklook information for an
@@ -879,11 +964,11 @@ class IonizationStateCollection:
         >>> states.summarize()
         IonizationStateCollection instance for: H, He
         ----------------------------------------------------------------
-        H  0+: 0.100    n_i = 3.00e+14 m**-3
-        H  1+: 0.900    n_i = 2.70e+15 m**-3
+        H  0+: 0.100    n_i = 3.00e+14 m**-3    T_i = 1.20e+04 K
+        H  1+: 0.900    n_i = 2.70e+15 m**-3    T_i = 1.20e+04 K
         ----------------------------------------------------------------
-        He  0+: 0.950    n_i = 2.85e+14 m**-3
-        He  1+: 0.050    n_i = 1.50e+13 m**-3
+        He  0+: 0.950    n_i = 2.85e+14 m**-3    T_i = 1.20e+04 K
+        He  1+: 0.050    n_i = 1.50e+13 m**-3    T_i = 1.20e+04 K
         ----------------------------------------------------------------
         n_e = 2.71e+15 m**-3
         T_e = 1.20e+04 K
@@ -911,11 +996,11 @@ class IonizationStateCollection:
 
         attributes = []
         if np.isfinite(self.n_e):
-            attributes.append("n_e = " + "{:.2e}".format(self.n_e.value) + " m**-3")
+            attributes.append(f"n_e = {self.n_e.value:.2e} m**-3")
         if np.isfinite(self.T_e):
-            attributes.append("T_e = " + "{:.2e}".format(self.T_e.value) + " K")
+            attributes.append(f"T_e = {self.T_e.value:.2e} K")
         if np.isfinite(self.kappa):
-            attributes.append("kappa = " + "{:.2f}".format(self.kappa))
+            attributes.append(f"kappa = {self.kappa:.2f}")
 
         if attributes:
             attributes.append(separator_line)
