@@ -13,11 +13,13 @@ from plasmapy.particles.exceptions import (
     ParticleError,
     ParticleWarning,
 )
+from plasmapy.utils.exceptions import PlasmaPyFutureWarning
 from plasmapy.utils.pytest_helpers import run_test
 
 from ..atomic import (
     _is_electron,
     atomic_number,
+    charge_number,
     common_isotopes,
     electric_charge,
     half_life,
@@ -335,7 +337,7 @@ is_stable_table = [
     [("B",), InvalidIsotopeError],
 ]
 
-integer_charge_table = [
+charge_number_table = [
     ["H+", 1],
     ["D +1", 1],
     ["tritium 1+", 1],
@@ -417,7 +419,7 @@ tables_and_functions = [
     (standard_atomic_weight, standard_atomic_weight_table),
     (is_stable, is_stable_table),
     (particle_mass, particle_mass_table),
-    (integer_charge, integer_charge_table),
+    (charge_number, charge_number_table),
     (electric_charge, electric_charge_table),
     (half_life, half_life_table),
 ]
@@ -463,7 +465,7 @@ atomic_ParticleErrors_funcs_table = [
     stable_isotopes,
     common_isotopes,
     isotopic_abundance,
-    integer_charge,
+    charge_number,
     electric_charge,
 ]
 
@@ -588,6 +590,7 @@ def test_particle_mass_equivalent_args(arg1, kwargs1, arg2, kwargs2, expected):
         )
 
 
+@pytest.mark.slow
 def test_known_common_stable_isotopes():
     """Test that `known_isotopes`, `common_isotopes`, and
     `stable_isotopes` return the correct values for hydrogen."""
@@ -666,6 +669,7 @@ def test_known_common_stable_isotopes_cases():
     assert "He-4" in common_isotopes("He", most_common_only=True)
 
 
+@pytest.mark.slow
 def test_known_common_stable_isotopes_len():
     """Test that `known_isotopes`, `common_isotopes`, and
     `stable_isotopes` each return a `list` of the expected length.
@@ -781,3 +785,8 @@ str_electron_table = [
 @pytest.mark.parametrize("particle, electron", str_electron_table)
 def test_is_electron(particle, electron):
     assert _is_electron(particle) == electron
+
+
+def test_integer_charge():
+    with pytest.warns(PlasmaPyFutureWarning):
+        assert integer_charge("Fe 20+") == 20
