@@ -94,7 +94,7 @@ parse_check_table = [
             "isotope": "He-4",
             "ion": "He-4 1+",
             "mass number": 4,
-            "integer charge": 1,
+            "charge number": 1,
         },
     ),
     (
@@ -106,7 +106,7 @@ parse_check_table = [
             "isotope": "He-4",
             "ion": "He-4 2+",
             "mass number": 4,
-            "integer charge": 2,
+            "charge number": 2,
         },
     ),
     (
@@ -117,7 +117,7 @@ parse_check_table = [
             "element": "H",
             "isotope": None,
             "ion": None,
-            "integer charge": None,
+            "charge number": None,
             "mass number": None,
         },
     ),
@@ -129,7 +129,7 @@ parse_check_table = [
             "element": "H",
             "isotope": "H-1",
             "ion": "p+",
-            "integer charge": 1,
+            "charge number": 1,
             "mass number": 1,
         },
     ),
@@ -141,7 +141,7 @@ parse_check_table = [
             "element": "H",
             "isotope": "D",
             "ion": None,
-            "integer charge": None,
+            "charge number": None,
             "mass number": 2,
         },
     ),
@@ -153,7 +153,7 @@ parse_check_table = [
             "element": "He",
             "isotope": None,
             "ion": None,
-            "integer charge": None,
+            "charge number": None,
             "mass number": None,
         },
     ),
@@ -165,7 +165,7 @@ parse_check_table = [
             "element": "H",
             "isotope": "T",
             "ion": "T 0+",
-            "integer charge": 0,
+            "charge number": 0,
             "mass number": 3,
         },
     ),
@@ -177,7 +177,7 @@ parse_check_table = [
             "element": "Fe",
             "isotope": "Fe-56",
             "ion": "Fe-56 7+",
-            "integer charge": 7,
+            "charge number": 7,
             "mass number": 56,
         },
     ),
@@ -189,7 +189,7 @@ parse_check_table = [
             "element": "H",
             "isotope": None,
             "ion": "H 1-",
-            "integer charge": -1,
+            "charge number": -1,
             "mass number": None,
         },
     ),
@@ -201,7 +201,7 @@ parse_check_table = [
             "element": "H",
             "isotope": "D",
             "ion": "D 1+",
-            "integer charge": 1,
+            "charge number": 1,
             "mass number": 2,
         },
     ),
@@ -213,7 +213,7 @@ parse_check_table = [
             "element": "Au",
             "isotope": None,
             "ion": None,
-            "integer charge": None,
+            "charge number": None,
             "mass number": None,
         },
     ),
@@ -225,7 +225,7 @@ parse_check_table = [
             "element": "Ar",
             "isotope": None,
             "ion": "Ar 2-",
-            "integer charge": -2,
+            "charge number": -2,
             "mass number": None,
         },
     ),
@@ -237,7 +237,7 @@ parse_check_table = [
             "element": "Fe",
             "isotope": "Fe-56",
             "ion": "Fe-56 24+",
-            "integer charge": 24,
+            "charge number": 24,
             "mass number": 56,
         },
     ),
@@ -249,7 +249,7 @@ parse_check_table = [
             "element": "Be",
             "isotope": "Be-8",
             "ion": "Be-8 3+",
-            "integer charge": 3,
+            "charge number": 3,
             "mass number": 8,
         },
     ),
@@ -261,7 +261,7 @@ parse_check_table = [
             "element": "H",
             "isotope": "H-1",
             "ion": "p+",
-            "integer charge": 1,
+            "charge number": 1,
             "mass number": 1,
         },
     ),
