@@ -1,7 +1,6 @@
 """Test that objects in `plasmapy.particles` can be pickled."""
 
 import astropy.units as u
-import os
 import pickle
 import pytest
 
@@ -19,17 +18,15 @@ class TestPickling:
     Test that different objects in `plasmapy.particles` can be pickled.
     """
 
-    xfail = pytest.mark.xfail(reason="see issue #1011")
-
     @pytest.mark.parametrize(
         "instance",
         [
             CustomParticle(mass=1 * u.kg, charge=1 * u.C),
             DimensionlessParticle(mass=5, charge=5),
-            pytest.param(Particle("p+"), marks=xfail),
-            pytest.param(IonicLevel("p+", 0.1, 1e9 * u.m ** -3), marks=xfail),
-            pytest.param(IonizationState("H", [0.5, 0.5]), marks=xfail),
-            pytest.param(IonizationStateCollection({"H": [0.5, 0.5]}), marks=xfail),
+            Particle("p+"),
+            IonicLevel("p+", 0.1, 1e9 * u.m ** -3),
+            IonizationState("H", [0.5, 0.5]),
+            IonizationStateCollection({"H": [0.5, 0.5]}),
         ],
     )
     def test_pickling(self, instance, tmp_path):
