@@ -26,7 +26,9 @@ from plasmapy.utils.exceptions import (
     CouplingWarning,
     PhysicsError,
     PhysicsWarning,
+    PlasmaPyDeprecationWarning,
     PlasmaPyError,
+    PlasmaPyFutureWarning,
     PlasmaPyWarning,
     RelativityError,
     RelativityWarning,
