@@ -6,6 +6,7 @@ __all__ = [
     "check_relativistic",
     "check_values",
     "check_units",
+    "deprecated",
     "modify_docstring",
     "preserve_signature",
     "validate_quantities",
@@ -24,5 +25,6 @@ from plasmapy.utils.decorators.checks import (
     CheckValues,
 )
 from plasmapy.utils.decorators.converter import angular_freq_to_hz
+from plasmapy.utils.decorators.deprecation import deprecated
 from plasmapy.utils.decorators.helpers import modify_docstring, preserve_signature
 from plasmapy.utils.decorators.validators import validate_quantities, ValidateQuantities
