@@ -149,9 +149,9 @@ class ValidateQuantities(CheckUnits, CheckValues):
 
         if "checks_on_return" in validations:
             raise TypeError(
-                f"keyword argument 'checks_on_return' is not allowed, "
-                f"use 'validations_on_return' to set validations "
-                f"on the return variable"
+                "keyword argument 'checks_on_return' is not allowed, "
+                "use 'validations_on_return' to set validations "
+                "on the return variable"
             )
 
         self._validations = validations
@@ -316,7 +316,7 @@ class ValidateQuantities(CheckUnits, CheckValues):
 
         # initialize str for error message
         if arg_name == "checks_on_return":
-            err_msg = f"The return value  "
+            err_msg = "The return value  "
         else:
             err_msg = f"The argument '{arg_name}' "
         err_msg += f"to function {self.f.__name__}()"
@@ -330,8 +330,8 @@ class ValidateQuantities(CheckUnits, CheckValues):
             typeerror_msg += f"{unit}"
 
             if ii != len(arg_validations["units"]) - 1:
-                typeerror_msg += f", "
-        typeerror_msg += f"]"
+                typeerror_msg += ", "
+        typeerror_msg += "]"
 
         # add units to arg if possible
         # * a None value will be taken care of by `_check_unit_core`
